==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/InferenceGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin

import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.InferenceGroupResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.ManagedServiceIdentityResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SkuResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.InferenceGroupResponse.Companion.toKotlin as inferenceGroupResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.ManagedServiceIdentityResponse.Companion.toKotlin as managedServiceIdentityResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SkuResponse.Companion.toKotlin as skuResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [InferenceGroup].
 */
@PulumiTagMarker
public class InferenceGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: InferenceGroupArgs = InferenceGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend InferenceGroupArgsBuilder.() -> Unit) {
        val builder = InferenceGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): InferenceGroup {
        val builtJavaResource =
            com.pulumi.azurenative.machinelearningservices.InferenceGroup(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return InferenceGroup(builtJavaResource)
    }
}

/**
 *
 * Azure REST API version: 2023-08-01-preview.
 * Other available API versions: 2024-01-01-preview.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:machinelearningservices:InferenceGroup string /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MachineLearningServices/workspaces/{workspaceName}/inferencePools/{poolName}/groups/{groupName}
 * ```
 */
public class InferenceGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.machinelearningservices.InferenceGroup,
) : KotlinCustomResource(javaResource, InferenceGroupMapper) {
    /**
     * Managed service identity (system assigned and/or user assigned identities)
     */
    public val identity: Output<ManagedServiceIdentityResponse>?
        get() = javaResource.identity().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    managedServiceIdentityResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * [Required] Additional attributes of the entity.
     */
    public val inferenceGroupProperties: Output<InferenceGroupResponse>
        get() = javaResource.inferenceGroupProperties().applyValue({ args0 ->
            args0.let({ args0 ->
                inferenceGroupResponseToKotlin(args0)
            })
        })

    /**
     * Metadata used by portal/tooling/etc to render different UX experiences for resources of the same type.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Sku details required for ARM contract for Autoscaling.
     */
    public val sku: Output<SkuResponse>?
        get() = javaResource.sku().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    skuResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object InferenceGroupMapper : ResourceMapper<InferenceGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.machinelearningservices.InferenceGroup::class == javaResource::class

    override fun map(javaResource: Resource): InferenceGroup = InferenceGroup(
        javaResource as
            com.pulumi.azurenative.machinelearningservices.InferenceGroup,
    )
}

/**
 * @see [InferenceGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [InferenceGroup].
 */
public suspend fun inferenceGroup(
    name: String,
    block: suspend InferenceGroupResourceBuilder.() -> Unit,
): InferenceGroup {
    val builder = InferenceGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [InferenceGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun inferenceGroup(name: String): InferenceGroup {
    val builder = InferenceGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/InferenceGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin

import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.InferenceGroupResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.ManagedServiceIdentityResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SkuResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.InferenceGroupResponse.Companion.toKotlin as inferenceGroupResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.ManagedServiceIdentityResponse.Companion.toKotlin as managedServiceIdentityResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SkuResponse.Companion.toKotlin as skuResponseToKotlin
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [InferenceGroup].
 */
@PulumiTagMarker
public class InferenceGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: InferenceGroupArgs = InferenceGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend InferenceGroupArgsBuilder.() -> Unit) {
        val builder = InferenceGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): InferenceGroup {
        val builtJavaResource =
            com.pulumi.azurenative.machinelearningservices.InferenceGroup(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return InferenceGroup(builtJavaResource)
    }
}

/**
 *
 * Azure REST API version: 2023-08-01-preview.
 * Other available API versions: 2024-01-01-preview, 2024-04-01-preview.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:machinelearningservices:InferenceGroup string /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MachineLearningServices/workspaces/{workspaceName}/inferencePools/{poolName}/groups/{groupName}
 * ```
 */
public class InferenceGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.machinelearningservices.InferenceGroup,
) : KotlinCustomResource(javaResource, InferenceGroupMapper) {
    /**
     * Managed service identity (system assigned and/or user assigned identities)
     */
    public val identity: Output<ManagedServiceIdentityResponse>?
        get() = javaResource.identity().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    managedServiceIdentityResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * [Required] Additional attributes of the entity.
     */
    public val inferenceGroupProperties: Output<InferenceGroupResponse>
        get() = javaResource.inferenceGroupProperties().applyValue({ args0 ->
            args0.let({ args0 ->
                inferenceGroupResponseToKotlin(args0)
            })
        })

    /**
     * Metadata used by portal/tooling/etc to render different UX experiences for resources of the same type.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Sku details required for ARM contract for Autoscaling.
     */
    public val sku: Output<SkuResponse>?
        get() = javaResource.sku().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    skuResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object InferenceGroupMapper : ResourceMapper<InferenceGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.machinelearningservices.InferenceGroup::class == javaResource::class

    override fun map(javaResource: Resource): InferenceGroup = InferenceGroup(
        javaResource as
            com.pulumi.azurenative.machinelearningservices.InferenceGroup,
    )
}

/**
 * @see [InferenceGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [InferenceGroup].
 */
public suspend fun inferenceGroup(
    name: String,
    block: suspend InferenceGroupResourceBuilder.() -> Unit,
): InferenceGroup {
    val builder = InferenceGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [InferenceGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun inferenceGroup(name: String): InferenceGroup {
    val builder = InferenceGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}
